<?php
/**
 * Call to action options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add featured section
$wp_customize->add_section( 'pikture_pro_call_to_action_section', array(
	'title'             => esc_html__( 'Call to action','pikture-pro' ),
	'description'       => esc_html__( 'Call to action options works only on Front page.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// Call to action content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_call_to_action_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_call_to_action_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_call_to_action_section]', array(
	'label'             => esc_html__( 'Call to action Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_call_to_action_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Call to action content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['call_to_action_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[call_to_action_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_call_to_action_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_call_to_action_enable',
	'choices'			=> pikture_pro_featured_content_type(),
) );

/**
 * Content type: Custom.
 */
// Call to action custom title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_custom_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['call_to_action_custom_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'pikture_pro_theme_options[call_to_action_custom_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_call_to_action_section',
	'active_callback' 	=> 'pikture_pro_is_call_to_action_custom_content_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[call_to_action_custom_title]', array(
		'selector'            => '#call-to-action h2.entry-title',
		'render_callback'     => 'pikture_pro_call_to_action_custom_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Call to action custom content control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_custom_content]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
	'transport'			=> 'postMessage',
	'default'          	=> $options['call_to_action_custom_content'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[call_to_action_custom_content]', array(
	'label'           => esc_html__( 'Content:', 'pikture-pro' ),
	'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
	'section'         => 'pikture_pro_call_to_action_section',
	'active_callback' => 'pikture_pro_is_call_to_action_custom_content_enable',
	'type'            => 'textarea',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[call_to_action_custom_content]', array(
		'selector'            => '#call-to-action .entry-content',
		'render_callback'     => 'pikture_pro_call_to_action_custom_content_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Call to action custom image control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_custom_image]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[call_to_action_custom_image]', array(
	'label'           => esc_html__( 'Image:', 'pikture-pro' ),
	'section'         => 'pikture_pro_call_to_action_section',
	'active_callback' => 'pikture_pro_is_call_to_action_custom_content_enable',
) ) );

// Call to action custom link text control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_custom_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['call_to_action_custom_btn_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[call_to_action_custom_btn_text]', array(
	'label'           => esc_html__( 'Button Text:', 'pikture-pro' ),
	'section'         => 'pikture_pro_call_to_action_section',
	'active_callback' => 'pikture_pro_is_call_to_action_content_demo_disable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[call_to_action_custom_btn_text]', array(
		'selector'            => '#call-to-action .btn.btn-white',
		'render_callback'     => 'pikture_pro_call_to_action_btn_txt_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Call to action custom link control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_custom_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'          	=> $options['call_to_action_custom_btn_link'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[call_to_action_custom_btn_link]', array(
	'label'           => esc_html__( 'Button Link:', 'pikture-pro' ),
	'section'         => 'pikture_pro_call_to_action_section',
	'active_callback' => 'pikture_pro_is_call_to_action_custom_content_enable',
) );

/**
 * Content Type: Page.
 */
// Call to action content type page control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_page_id]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_page',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[call_to_action_page_id]', array(
	'label'           => esc_html__( 'Page:', 'pikture-pro' ),
	'description'     => esc_html__( "Title, content, url and image will be used from the selected page's title, trimmed content, permalink and featured image respectively.", 'pikture-pro' ),
	'active_callback' => 'pikture_pro_is_call_to_action_page_content_enable',
	'section'         => 'pikture_pro_call_to_action_section',
	'type'            => 'dropdown-pages',
) );

/**
 * Content type: Post.
 */
// Call to action content type post control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[call_to_action_post_id]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_page',
) );

$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[call_to_action_post_id]', array(
	'label'           => esc_html__( 'Post:', 'pikture-pro' ),
	'description'     => esc_html__( "Title, content, url and image will be rendered from the selected post's title, excerpt, permalink and featured image respectively.", 'pikture-pro' ),
	'active_callback' => 'pikture_pro_is_call_to_action_post_content_enable',
	'section'         => 'pikture_pro_call_to_action_section',
	'choices'         => pikture_pro_posts_choices(),
) ) );