<?php
/**
 * Counter options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

$query['autofocus[control]'] = 'pikture_pro_theme_options[enable_about_section]';
$about_ctrl_link = add_query_arg( $query, admin_url( 'customize.php' ) );

// Add featured section
$wp_customize->add_section( 'pikture_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','pikture-pro' ),
	'description'       => sprintf( esc_html__( 'Counter options works only on Front page and when %1$sAbout section %2$s is enabled.', 'pikture-pro' ),  '<a rel="pikture-counter" href="' . esc_url( $about_ctrl_link ) . '">', '</a>' ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_counter_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_counter_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_counter_section]', array(
	'label'             => esc_html__( 'Counter Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_counter_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

for ( $i=1; $i < 4; $i++ ) { 
	// Counter icon control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[counter_icon_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_select',
		'default'          	=> $options['counter_icon'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[counter_icon_'.$i.']', array(
		'label'             => esc_html__( 'Icon ', 'pikture-pro' ) . $i,
		'section'           => 'pikture_pro_counter_section',
		'type' 				=> 'select',
		'active_callback'	=> 'pikture_pro_is_counter_enable',
		'choices'			=> pikture_pro_get_counter_list()
	) );

	// Counter count control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[counter_count_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_number_range',
		'default'          	=> $options['counter_count'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[counter_count_'.$i.']', array(
		'label'             => esc_html__( 'Count ', 'pikture-pro' ) . $i,
		'section'           => 'pikture_pro_counter_section',
		'type' 				=> 'number',
		'active_callback'	=> 'pikture_pro_is_counter_enable',
		'input_attrs'		=> array( 'min' => 0 ),
	) );

	// Counter text control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[counter_text_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['counter_text'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[counter_text_'.$i.']', array(
		'label'             => esc_html__( 'Text ', 'pikture-pro' ) . $i,
		'active_callback'	=> 'pikture_pro_is_counter_enable',
		'section'           => 'pikture_pro_counter_section',
	) );

	// Counter separator control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[counter_hr_line_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[counter_hr_line_'.$i.']', array(
		'active_callback'	=> 'pikture_pro_is_counter_enable',
		'section'           => 'pikture_pro_counter_section',
	) ) );
}