<?php
/**
 * About template portfolio options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add about template portfolio section
$wp_customize->add_section( 'pikture_pro_about_temp_portfolio', array(
	'title'             => esc_html__( 'Portfolio','pikture-pro' ),
	'description'       => esc_html__( 'Portfolio options( Works only on page with "About Us" template assigned. ). Images with ratio of 2:3 would look the best in this section.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_about_us_panel',
) );

// Portfolio content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_about_temp_portfolio_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_about_temp_portfolio_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_about_temp_portfolio_section]', array(
	'label'             => esc_html__( 'Portfolio Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_portfolio',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['about_temp_portfolio_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_portfolio',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_about_temp_portfolio_enable',
	'choices'			=> pikture_pro_featured_content_type(),
) );

/**
 * Content type: Custom.
 */
// Portfolio custom title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_custom_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_temp_portfolio_custom_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_custom_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_portfolio',
	'active_callback' 	=> 'pikture_pro_is_about_temp_portfolio_custom_content_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_portfolio_custom_title]', array(
		'selector'            => '#portfolio h2.entry-title',
		'render_callback'     => 'pikture_pro_about_temp_portfolio_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portfolio custom sub title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_custom_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_temp_portfolio_custom_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_custom_sub_title]', array(
	'label'             => esc_html__( 'Sub Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_portfolio',
	'active_callback' 	=> 'pikture_pro_is_about_temp_portfolio_demo_content_disabled',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_portfolio_custom_sub_title]', array(
		'selector'            => '#portfolio span.sub-title',
		'render_callback'     => 'pikture_pro_about_temp_portfolio_sub_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portfolio custom content control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_custom_content]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
	'transport'			=> 'postMessage',
	'default'          	=> $options['about_temp_portfolio_custom_content'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_custom_content]', array(
	'label'           => esc_html__( 'Content:', 'pikture-pro' ),
	'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_temp_portfolio',
	'active_callback' => 'pikture_pro_is_about_temp_portfolio_custom_content_enable',
	'type'            => 'textarea',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_portfolio_custom_content]', array(
		'selector'            => '#portfolio .entry-content',
		'render_callback'     => 'pikture_pro_about_temp_portfolio_content_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portfolio custom name control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_custom_name]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_temp_portfolio_custom_name'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_custom_name]', array(
	'label'             => esc_html__( 'Name:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_portfolio',
	'active_callback' 	=> 'pikture_pro_is_about_temp_portfolio_demo_content_disabled',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_portfolio_custom_name]', array(
		'selector'            => '#portfolio .position h5',
		'render_callback'     => 'pikture_pro_about_temp_portfolio_name_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portfolio custom position control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_custom_position]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_temp_portfolio_custom_position'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_custom_position]', array(
	'label'             => esc_html__( 'Position:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_portfolio',
	'active_callback' 	=> 'pikture_pro_is_about_temp_portfolio_demo_content_disabled',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_portfolio_custom_position]', array(
		'selector'            => '#portfolio .position .designation',
		'render_callback'     => 'pikture_pro_about_temp_portfolio_position_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portfolio custom image control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_custom_image]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[about_temp_portfolio_custom_image]', array(
	'label'           => esc_html__( 'Image:', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_temp_portfolio',
	'active_callback' => 'pikture_pro_is_about_temp_portfolio_custom_content_enable',
) ) );


/**
 * Content Type: Page.
 */
// Portfolio content type page control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_page_id]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_page',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_portfolio_page_id]', array(
	'label'             => esc_html__( 'Page:', 'pikture-pro' ),
	'description'             => esc_html__( "Title, content and image will be used from the selected page's title, content and featured image respectively.", 'pikture-pro' ),
	'active_callback' 	=> 'pikture_pro_is_about_temp_portfolio_page_content_enable',
	'section'           => 'pikture_pro_about_temp_portfolio',
	'type'				=> 'dropdown-pages',
) );

/**
 * Content type: Post.
 */
// Portfolio content type post control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_portfolio_post_id]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_page',
) );

$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[about_temp_portfolio_post_id]', array(
	'label'           => esc_html__( 'Post:', 'pikture-pro' ),
	'description'     => esc_html__( "Title, content and image will be rendered from the selected post's title, content and featured image respectively.", 'pikture-pro' ),
	'active_callback' => 'pikture_pro_is_about_temp_portfolio_post_content_enable',
	'section'         => 'pikture_pro_about_temp_portfolio',
	'choices'         => pikture_pro_posts_choices(),
) ) );