<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function pikture_pro_body_classes( $classes ) {
	$options = pikture_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// Add a class for sidebar
	$sidebar_position = pikture_pro_layout();

	if ( is_active_sidebar( 'sidebar-1' ) && ! ( pikture_pro_is_woocommerce_activated() && pikture_pro_is_woocommerce() ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} elseif( pikture_pro_is_woocommerce_activated() && pikture_pro_is_woocommerce() ) {
		if ( is_active_sidebar( 'woo-sidebar' ) ) {
			if ( is_cart() || is_checkout() || is_account_page() ) {
				$woo_pages_sidebar_position = get_post_meta( get_the_id(), 'pikture_pro_sidebar_layout', true );
				if ( $woo_pages_sidebar_position ) {
					$classes[] = esc_attr( $woo_pages_sidebar_position );
				} else {
					$classes[] = esc_attr( $options['woo_sidebar_position'] );
				}
			} else {
				$classes[] = esc_attr( $options['woo_sidebar_position'] );
			}
		} else {
			$classes[] = 'no-sidebar';
		}
	} else {
		$classes[] = 'no-sidebar';
	}

	$classes[] = ( $options['menu_sticky'] ) ? 'sticky-menu' : '' ;

	$classes[] = ( 'classic' === $options['menu_type'] ) ? 'classic-menu' : 'modern-menu';

	$colors = esc_attr( $options['colorscheme'] );
	$classes[] = 'colors-' . $colors;

	$classes[] = 'accent-colors';

	return $classes;
}
add_filter( 'body_class', 'pikture_pro_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function pikture_pro_post_classes( $classes ) {
	$options = pikture_pro_get_theme_options();
	
	$hide_img = $options['hide_image'];

	if ( ! has_post_thumbnail() || $hide_img ) {
		$classes[] = 'has-no-post-thumbnail';
		if ( in_array('has-post-thumbnail', $classes ) ) {
		    unset( $classes[ array_search( 'has-post-thumbnail',$classes ) ] );
		}
	}

	return $classes;
}
add_filter( 'post_class', 'pikture_pro_post_classes' );