<?php
/**
 * Pikture options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

if ( ! function_exists( 'pikture_pro_enable_options' ) ) :
    /**
     * List of enabling options
     * @return Array Array of enabling options
     */
    function pikture_pro_enable_options() {
        $pikture_pro_enable_options = array(
            'front-page'  => esc_html__( 'Front Page Only.', 'pikture-pro' ),
            'entire-site' => esc_html__( 'Entire Site.', 'pikture-pro' ),
            'none'        => esc_html__( 'None.', 'pikture-pro' ),
        );

        $output = apply_filters( 'pikture_pro_enable_options', $pikture_pro_enable_options );
        return $output;
    }
endif;

if ( ! function_exists( 'pikture_pro_featured_content_type' ) ) :
    /**
     * List of content type for featured section content.
     * @return Array Array of featured section content.
     */
    function pikture_pro_featured_content_type() {
        $pikture_pro_featured_content_type = array(
            'demo'      => esc_html__( 'Demo', 'pikture-pro' ),
            'custom'    => esc_html__( 'Custom', 'pikture-pro' ),
            'page'      => esc_html__( 'Page', 'pikture-pro' ),
            'post'      => esc_html__( 'Post', 'pikture-pro' ),
        );

        $output = apply_filters( 'pikture_pro_featured_content_type', $pikture_pro_featured_content_type );
        return $output;
    }
endif;

if ( ! function_exists( 'pikture_pro_client_content_type' ) ) :
    /**
     * List of content type for client section content.
     * @return Array Array of client section content.
     */
    function pikture_pro_client_content_type() {
        $pikture_pro_client_content_type = array(
            'demo'      => esc_html__( 'Demo', 'pikture-pro' ),
            'custom'    => esc_html__( 'Custom', 'pikture-pro' ),
            'category' => esc_html__( 'Category', 'pikture-pro' ),
            'page'      => esc_html__( 'Page', 'pikture-pro' ),
            'post'      => esc_html__( 'Post', 'pikture-pro' ),
        );

        $output = apply_filters( 'pikture_pro_client_content_type', $pikture_pro_client_content_type );
        return $output;
    }
endif;

if ( ! function_exists( 'pikture_pro_panorama_content_type' ) ) :
    /**
     * List of content type for panorama section content.
     * @return Array Array of panorama section content.
     */
    function pikture_pro_panorama_content_type() {
        $pikture_pro_panorama_content_type = array(
            'demo'     => esc_html__( 'Demo', 'pikture-pro' ),
            'category' => esc_html__( 'Category', 'pikture-pro' ),
            'gallery'  => esc_html__( 'Gallery', 'pikture-pro' ),
            'page'     => esc_html__( 'Page', 'pikture-pro' ),
            'post'     => esc_html__( 'Post', 'pikture-pro' ),
        );

        $output = apply_filters( 'pikture_pro_panorama_content_type', $pikture_pro_panorama_content_type );
        return $output;
    }
endif;

if ( ! function_exists( 'pikture_pro_typography_options' ) ) :
    /**
    * Returns list of typography
    * @return array font styles
    */
    function pikture_pro_typography_options(){

        $choices = array(
            'default'         => esc_html__( 'Default', 'pikture-pro' ),
            'news-cycle'     => esc_html__( 'News Cycle', 'pikture-pro' ),
            'pontano-sans'     => esc_html__( 'Pontano Sans', 'pikture-pro' ),
            'gudea'     => esc_html__( 'Gudea', 'pikture-pro' ),
            'quattrocento'     => esc_html__( 'Quattrocento', 'pikture-pro' ),
            'khand'     => esc_html__( 'Khand', 'pikture-pro' ),
        );
        $output = apply_filters( 'pikture_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }
        return $output;
    }
endif;


if ( ! function_exists( 'pikture_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function pikture_pro_site_layout() {
        $pikture_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'pikture_pro_site_layout', $pikture_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'pikture_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function pikture_pro_sidebar_position() {
        $pikture_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'pikture_pro_sidebar_position', $pikture_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'pikture_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function pikture_pro_pagination_options() {
        $pikture_pro_pagination_options = array(
            'numeric'  => esc_html__( 'Numeric', 'pikture-pro' ),
            'default' => esc_html__( 'Default(Older/Newer)', 'pikture-pro' ),
        );

        $output = apply_filters( 'pikture_pro_pagination_options', $pikture_pro_pagination_options );

        return $output;
    }
endif;



if ( ! function_exists( 'pikture_pro_get_image_sizes_options' ) ) :

    /**
     * Returns image sizes options.
     *
     * @since 1.0.0
     *
     * @param bool  $add_disable True for adding No Image option.
     * @return array Image size options.
    */
    function pikture_pro_get_image_sizes_options( $add_disable = true, $show_dimension = true ) {

        global $_wp_additional_image_sizes;
        $get_intermediate_image_sizes = get_intermediate_image_sizes();
        $choices = array();

        if ( true === $add_disable ) {
            $choices['disable'] = esc_html__( 'No Image', 'pikture-pro' );
        }

        $choices['thumbnail'] = esc_html__( 'Thumbnail', 'pikture-pro' );
        $choices['medium']    = esc_html__( 'Medium', 'pikture-pro' );
        $choices['large']     = esc_html__( 'Large', 'pikture-pro' );
        $choices['full']      = esc_html__( 'Full (original)', 'pikture-pro' );

        if ( true === $show_dimension ) {
            foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
                $choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
            }
        }

        if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
            foreach ( $_wp_additional_image_sizes as $key => $size ) {
                
                $choices[ $key ] = $key;
                if ( true === $show_dimension ){
                    $choices[ $key ] .= ' (' . $size['width'] . 'x' . $size['height'] . ')';
                }
            }
        }
        return $choices;
    }
endif;

if ( ! function_exists( 'pikture_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function pikture_pro_get_spinner_list() {
        $arr = array(
            'spinner-wheel'         => esc_html__( 'Wheel', 'pikture-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'pikture-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'pikture-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'pikture-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'pikture-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'pikture-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'pikture-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'pikture-pro' ),
        );
        return apply_filters( 'pikture_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'pikture_pro_get_counter_list' ) ) :
    /**
     * List of counter icons options.
     * @return array List of all counter icon options.
     */
    function pikture_pro_get_counter_list() {
        $arr = array(
            ''             => esc_html__( '-- Select --', 'pikture-pro' ),
            'gallery'      => esc_html__( 'Gallery', 'pikture-pro' ),
            'cloud'        => esc_html__( 'Cloud', 'pikture-pro' ),
            'thumb-up'     => esc_html__( 'Thumb Up', 'pikture-pro' ),
            'briefcase'    => esc_html__( 'Briefcase', 'pikture-pro' ),
            'coffee-cup'   => esc_html__( 'Coffee Cup', 'pikture-pro' ),
            'flag'         => esc_html__( 'Flag', 'pikture-pro' ),
            'home'         => esc_html__( 'Home', 'pikture-pro' ),
            'internet'     => esc_html__( 'Internet', 'pikture-pro' ),
            'layers'       => esc_html__( 'Layers', 'pikture-pro' ),
            'light-bulb'   => esc_html__( 'Light Bulb', 'pikture-pro' ),
            'paper-plane'  => esc_html__( 'Paper Plane', 'pikture-pro' ),
            'settings'     => esc_html__( 'Settings', 'pikture-pro' ),
            'star'         => esc_html__( 'Star', 'pikture-pro' ),
            'umbrella'     => esc_html__( 'Umbrella', 'pikture-pro' ),
            'users'        => esc_html__( 'Users', 'pikture-pro' ),
            'video-player' => esc_html__( 'Video Player', 'pikture-pro' ),
            'heart'        => esc_html__( 'Heart', 'pikture-pro' ),
            'alarm-clock'  => esc_html__( 'Alarm Clock', 'pikture-pro' ),
            'like'         => esc_html__( 'Like', 'pikture-pro' ),
            'collection'   => esc_html__( 'Collection', 'pikture-pro' ),
            'download'     => esc_html__( 'Download', 'pikture-pro' ),
            'television'   => esc_html__( 'Television', 'pikture-pro' ),
        );
        ksort( $arr );
        return apply_filters( 'pikture_pro_counter_list', $arr );
    }
endif;

if ( ! function_exists( 'pikture_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function pikture_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'pikture-pro' ),
            'off'       => esc_html__( 'No', 'pikture-pro' )
        );
        return apply_filters( 'pikture_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'pikture_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function pikture_pro_sortable_sections() {
        $sections = array(
            'featured'       => esc_html__( 'Featured', 'pikture-pro' ),
            'counter_about'  => esc_html__( 'Counter and About', 'pikture-pro' ),
            'panorama'       => esc_html__( 'Panorama', 'pikture-pro' ),
            'call_to_action' => esc_html__( 'Call To Action', 'pikture-pro' ),
            'portrait'       => esc_html__( 'Portrait', 'pikture-pro' ),
            'client'         => esc_html__( 'Client', 'pikture-pro' ),
            'landscape'      => esc_html__( 'Landscape', 'pikture-pro' ),
            'testimonial'    => esc_html__( 'Testimonial', 'pikture-pro' ),
        );
        return apply_filters( 'pikture_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'pikture_pro_posts_choices' ) ) :
    /**
     * List of posts choices
     * @return Array Array of posts
     */
    function pikture_pro_posts_choices() {
        $latest = new WP_Query( array(
            'post_type'   => 'post',
            'post_status' => 'publish',
            'orderby'     => 'post_title',
            'order'       => 'ASC',
            'posts_per_page' => -1,
            'cache_results'  => true,
        ));

        $pikture_pro_posts_choices = array();
        if ( $latest->have_posts() ) {
            while( $latest->have_posts() ) {
                $latest->the_post(); 
                
                    $id = get_the_ID();
                    $title = get_the_title();
                    $pikture_pro_posts_choices[ $id ] = $title;
            }
        }

        $output = apply_filters( 'pikture_pro_posts_choices', $pikture_pro_posts_choices );
        return $output;
    }
endif;