<?php
/**
 * About us template contact section
 *
 * This is the template for the about template contact section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_about_temp_contact_section' ) ) :
  /**
   * Add about template contact section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_about_temp_contact_section() {
    // Check if about template contact is enabled.
    $options = pikture_pro_get_theme_options();

	if ( ! $options['enable_about_temp_contact'] ){
        return false;
    }

    // Render about template contact section now.
    pikture_pro_render_about_temp_contact_section();
  }
endif;
add_action( 'pikture_pro_about_us_template', 'pikture_pro_add_about_temp_contact_section', 40 );


if ( ! function_exists( 'pikture_pro_render_about_temp_contact_section' ) ) :
  /**
   * Start about template contact section
   *
   * @return string About template contact content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_about_temp_contact_section() {
        $options          = pikture_pro_get_theme_options();

        $bg_img = ( isset( $options['about_temp_contact_image'] ) ) ? $options['about_temp_contact_image'] : '';
        $class = ( $bg_img ) ? '' : 'full-width';
        ?>

        <div id="get-in-touch" class="<?php echo esc_attr( $class ); ?> clear">
            <?php if ( $bg_img ): ?>
                <div class="featured-image" style="background-image: url('<?php echo esc_url( $bg_img ); ?>')">
                </div><!-- .featured-image -->
            <?php endif ?>

            <div class="contact-info">
                <header class="entry-header">
                    <?php if ( isset( $options['about_temp_contact_sub_title'] ) ) : ?>
                        <span class="sub-title"><?php echo esc_html( $options['about_temp_contact_sub_title'] ); ?></span>
                    <?php endif; ?>
                    <?php if ( isset( $options['about_temp_contact_title'] ) ) : ?>
                        <h2 class="entry-title"><?php echo esc_html( $options['about_temp_contact_title'] ); ?></h2>
                    <?php endif; ?>
                    <div class="seperator"></div>
                </header><!-- .entry-header -->


                <?php if ( isset( $options['about_temp_contact_content'] ) ) : ?>
                    <div class="entry-content">
                        <?php echo wp_kses_post( $options['about_temp_contact_content'] ); ?>
                    </div><!-- .entry-content -->
                <?php endif; ?>

                <?php if ( isset( $options['about_temp_contact_shortcode'] ) ) : ?>
                    <div class="contact-form">
                    <?php echo do_shortcode( $options['about_temp_contact_shortcode'] );?>
                    </div>
                <?php endif; ?>

            </div>
        </div><!-- #get-in-touch -->
<?php
    }
endif;