<?php
/**
 * Testimonial section
 *
 * This is the template for the testimonial section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_testimonial_section' ) ) :
  /**
   * Add testimonial section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_testimonial_section() {
    // Check if testimonial is enabled on frontpage
    $enable_testimonial_section = apply_filters( 'pikture_pro_section_status', true, 'enable_testimonial_section' );
    
    if ( true !== $enable_testimonial_section ) {
        return false;
    }

    // Get testimonial section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_testimonial_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render testimonial section now.
    pikture_pro_render_testimonial_section( $section_details );
  }
endif;
add_action( 'pikture_pro_content_start_action', 'pikture_pro_add_testimonial_section', 20 );


if ( ! function_exists( 'pikture_pro_get_testimonial_section_details' ) ) :
  /**
   * testimonial section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input testimonial section details.
   */
  function pikture_pro_get_testimonial_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $testimonial_content_type  = $options['testimonial_content_type'];
    $content = array();
    switch ( $testimonial_content_type ) {
        case 'demo':
            for ( $i = 1; $i < 6; $i++ ) { 
                $demo['img']       = get_template_directory_uri() . '/assets/uploads/testimonial-bg.jpg';
                $demo['content']  = esc_html__( 'Amazing photography, great person to work with. Would like to work more in future. Lorem ipsum dolor sit amet tempor neque.', 'pikture-pro' );
                $demo['name'] = esc_html__( 'Meagan Fisher', 'pikture-pro' );
                $demo['position'] = esc_html__( 'UI/UX Designer', 'pikture-pro' );

                // Push to the main array.
                array_push( $content, $demo );
            }
        break;

        case 'custom':
            for ( $i=1; $i <= $options['testimonial_num']; $i++ ) {
                $custom['img'] = ( isset( $options['testimonial_custom_image_' . $i ] ) ) ? $options['testimonial_custom_image_' . $i ] : '';
                $custom['content'] = ( isset( $options['testimonial_custom_content_' . $i] ) ) ? $options['testimonial_custom_content_' . $i] : $options['testimonial_custom_content'];
                $custom['name']  = ( isset( $options['testimonial_custom_name_' . $i] ) ) ? $options['testimonial_custom_name_' . $i] : $options['testimonial_custom_name'];
                $custom['position']  = ( isset( $options['testimonial_custom_position_' . $i] ) ) ? $options['testimonial_custom_position_' . $i] : $options['testimonial_custom_position'];

                // Push to the main array.
                array_push( $content, $custom );
                $content = array_filter( $content );
            }
        break;

        case 'category':
            if ( isset( $options['testimonial_category'] ) ) {
                $id = $options['testimonial_category'];
            }
        break;

        case 'page':
            $id = array();
            for ( $i=1; $i <= $options['testimonial_num']; $i++ ) {
                if ( isset( $options['testimonial_page_id_' . $i ] ) ) {
                    array_push( $id, $options['testimonial_page_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id = array_filter( $id );
        break;

        case 'post':
            $id = array();
            for ( $i=1; $i <= $options['testimonial_num']; $i++ ) {
                if ( isset( $options['testimonial_post_id_' . $i ] ) ) {
                    array_push( $id, $options['testimonial_post_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id = array_filter( $id );
        break;

        default:
        break;
    }
    if ( 'category' === $testimonial_content_type || 'post' === $testimonial_content_type || 'page' === $testimonial_content_type ) {
        if( ! empty ( $id ) ) {
            // Prepare arguments.
            $args = array(
                'ignore_sticky_posts' => true,
                'posts_per_page'      => $options['testimonial_num'],
                'orderby'             => 'post__in'
            );

            $conditional_args = array();
            if ( 'category' === $testimonial_content_type ) {
                $args['cat'] = absint( $id );
            } else {
                $args['post_type'] = $testimonial_content_type;
                $args['post__in']  = $id;
            }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['img']     = get_the_post_thumbnail_url();
                    // Check if it is post or page. If post get excerpt. If page, strip the content.
                    $post_type            = get_post_type();
                    $raw_content          = ( 'post' == $post_type ) ? get_the_excerpt() : pikture_pro_trim_content( 50 ) ;
                    $page_post['content'] = $raw_content;
                    $page_post['name']    = get_the_title();
                    $page_post['url']     = get_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Testimonial section content details.
add_filter( 'pikture_pro_filter_testimonial_section_details', 'pikture_pro_get_testimonial_section_details' );


if ( ! function_exists( 'pikture_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string Testimonial content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_testimonial_section( $content_details = array() ) {
        $options        = pikture_pro_get_theme_options();

        $testimonial_left_part = $options['enable_testimonial_left_part'];
        $class = ( $testimonial_left_part ) ? 'col-2' : 'col-1';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="testimonial" class="page-section no-padding-top <?php echo esc_attr( $class ); ?> relative">

            <?php if ( $testimonial_left_part ) : ?>
                <div class="hentry">
                    <div class="testimonial-content">
                        <header class="entry-header align-left">
                            <span class="sub-title"><?php echo esc_html( $options['testimonial_sub_title'] ); ?></span>
                            <h2 class="entry-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                            <div class="seperator"></div>
                        </header><!-- .entry-header -->

                        <div class="entry-content">
                            <?php echo pikture_pro_sanitize_html( $options['testimonial_content'] ); ?>
                        </div><!-- .entry-content -->

                    </div><!-- .testimonial-content -->
                </div><!-- .hentry -->
            <?php endif; ?>
            
            <div class="hentry">
                <div class="regular" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": false, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "fade": false, "draggable": trues }'>

                    <?php foreach ( $content_details as $content ) : 
                        $slider_class = ( $content['img'] ) ? 'half-width' : 'full-width';
                        ?>
                        <div class="testimonial-slider">
                            <?php if ( ! empty( $content['img'] ) ) : ?>
                                <div class="half-width">
                                    <div class="slider-item" style="background-image: url('<?php echo esc_url( $content['img'] ); ?>');">
                                    </div><!-- .slider-item -->

                                </div>
                            <?php endif; ?>
                            <div class="<?php echo esc_attr( $slider_class ); ?>">
                                <div class="slider-content">
                                    <div class="flex">
                                        <blockquote><?php echo wp_kses_post( $content['content'] ) ?></blockquote>
                                        <div class="position">
                                            <h5>
                                                <?php if ( isset( $content['url'] ) ) : ?>
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <?php endif; ?>
                                                    <?php echo esc_html( $content['name'] ); ?>        
                                                <?php if ( isset( $content['url'] ) ) : ?>
                                                    </a>
                                                <?php endif; ?>
                                            </h5>
                                            <?php if ( isset( $content['position'] ) ) : ?>
                                                <span><?php echo esc_html( $content['position'] ); ?></span>
                                            <?php endif; ?>
                                        </div><!-- .position -->
                                    </div><!-- .flex -->
                                </div><!-- .slider-content -->
                            </div>
                        </div>
                    <?php endforeach; ?>

                </div><!-- .regular -->
            </div><!-- .hentry -->
        </div><!-- #Testimonial -->
<?php
    }
endif;